@@ -20,8 +20,16 @@
 [comment]: # file targets, such as build, you will need to include pandoc in
 [comment]: # your Build-Depends control field.
 
+[comment]: # lowdown is a low dependency, lightweight alternative to
+[comment]: # pandoc as a markdown to manpage translator. Use with:
+[comment]: # 
+[comment]: # package.1: package.md
+[comment]: #         lowdown -s -Tman -o $@ $<
+[comment]: # 
+[comment]: # And add lowdown to the Build-Depends control field.
+
 [comment]: # Remove the lines starting with '[comment]:' in this file in order
-[comment]: # to avoid warning messages from pandoc.
+[comment]: # to avoid warning messages.
 
 # NAME
 
